@@ -74,6 +74,30 @@ class BalanceError(Exception):
         return f"{self.error_message}"
 
 
+class SymbolError(Exception):
+
+    def __init__(self, error_message, error_detail=None):
+        self.error_message = error_message
+        self.error_detail = error_detail
+
+    def __str__(self):
+        if self.error_detail:
+            return f"{self.error_message}, {self.error_detail}"
+        return f"{self.error_message}"
+
+
+class DerivationError(Exception):
+
+    def __init__(self, error_message, error_detail=None):
+        self.error_message = error_message
+        self.error_detail = error_detail
+
+    def __str__(self):
+        if self.error_detail:
+            return f"{self.error_message}, {self.error_detail}"
+        return f"{self.error_message}"
+
+
 class NetworkError(Exception):
 
     def __init__(self, error_message, error_detail=None):
