@@ -1,22 +1,17 @@
 #!/usr/bin/env python3
 
+from typing import List
+
 from .script import (
     get_public_key_hash, get_script_hash,
     get_p2pkh_program, get_p2sh_program,
     get_p2wpkh_program, get_p2wsh_program,
-    get_p2wpkh_address, get_p2wsh_address,
-    get_p2wpkh_vapor_address, get_p2wsh_vapor_address
+    get_p2wpkh_address, get_p2wsh_address
 )
 
-
-__all__ = [
-    # Hash
+__all__: List[str] = [
     "get_public_key_hash", "get_script_hash",
-    # Program
     "get_p2wpkh_program", "get_p2wsh_program",
     "get_p2pkh_program", "get_p2sh_program",
-    # Address
-    "get_p2wpkh_address", "get_p2wsh_address",
-    # Vapor address
-    "get_p2wpkh_vapor_address", "get_p2wsh_vapor_address"
+    "get_p2wpkh_address", "get_p2wsh_address"
 ]
